@@ -1,6 +1,7 @@
-library(filters)
-
 test_that("Listing print correctly", {
+  testthat::skip_if_not_installed("filters")
+  require(filters)
+
   # skip_if_too_deep(1)
   load_filters(file.path(system.file(package = "autoslider.core"), "filters.yml"), overwrite = TRUE)
 
